pub struct BundleCache<'this, T> { /* private fields */ }Expand description
A cache wrapper for another bundle.
This bundle implementation is the key to Tectonic’s ability to download TeX
support files on the fly. This is usually used to wrap some kind of network-
based bundle, but can be used with any struct that implements Bundle.
The caching scheme here is designed so that a document build may avoid touching the network altogether if no new files need to be downloaded.
Implementations
Sourceimpl<'this, T: FileIndex<'this>> BundleCache<'this, T>
impl<'this, T: FileIndex<'this>> BundleCache<'this, T>
Sourcepub fn new(
bundle: Box<dyn CachableBundle<'this, T>>,
only_cached: bool,
cache_root: Option<PathBuf>,
) -> Result<Self>
pub fn new( bundle: Box<dyn CachableBundle<'this, T>>, only_cached: bool, cache_root: Option<PathBuf>, ) -> Result<Self>
Make a new filesystem-backed cache from bundle.
This method will fail if we can’t connect to the bundle AND we don’t already have it in our cache. Other than that, this method does not require network access.